cutgeneratingfunctionology: Python code for computation and experimentation with cut-generating functions
=========================================================================================================

Description
-----------

Python code for computation and experimentation with cut-generating functions

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/cutgeneratingfunctionology/

